@@ -31,6 +31,9 @@ class LogseqPage:
         assert isinstance(content, str), (
             f"content must be of type string, not '{type(content)}'")
 
+        content = content.strip()
+        assert content, "Cannot supply empty content"
+
         # detect each block (read each line then merge with the latest block)
         lines = content.split("\n")
 
